MenuOpenedEvent

Struct MenuOpenedEvent 

pub struct MenuOpenedEvent {
    pub entity: Entity,
    pub window_id: i32,
    pub menu_type: MenuKind,
    pub title: FormattedText,
}
A Bevy trigger that’s fired when our client should show a new screen (like a chest or crafting table).

To watch for the menu being closed, you could use ClientsideCloseContainerEvent. To close it manually, use CloseContainerEvent.

Fields

entity: Entitywindow_id: i32menu_type: MenuKindtitle: FormattedText